import { Component, ElementRef, ViewChild } from "@angular/core";
import { Router } from "@angular/router";
import { DeviceService } from "../../service/device.service";
import { BuildingService } from "../../service/monitoring-api.service";
import videojs from "video.js";

@Component({
  selector: "app-surveillance",
  templateUrl: "./surveillance.component.html",
  styleUrls: ["./surveillance.component.css"],
})
export class SurveillanceComponent {
  @ViewChild('videoIframe', { static: false }) videoIframe: ElementRef;

  filteredRows: any[];
  searchTerm: string = "";
  buildingSelected: any;
  statusSelected: any;
  categorySelected: any;
  dataMasterCategori: any;
  dataBuildingList: any;
  dataMasterStatus: any;
  storedData: any;
  spinnerFilterActive = false;
  switchState: boolean;

  public breadcrumb: any;

  constructor(
    private router: Router,
    private deviceService: DeviceService,
    private monitoringApiService: BuildingService
  ) {}

  ngOnInit() {
    this.breadcrumb = {
      mainlabel: "Device",
      links: [
        {
          name: "Home",
          isLink: false,
          link: "/dashboard/sales",
        },
        {
          name: "Device",
          isLink: false,
        },
      ],
    };
    this.storedData = JSON.parse(localStorage.getItem("currentUser"));
    this.buildingSelected = this.storedData.buildingId;
    this.fetchData(
      this.buildingSelected,
      this.categorySelected,
      this.statusSelected
    );
    this.dataListMaster();
    this.dataListBuilding();
  }

  ngAfterViewInit() {
    //Called after ngAfterContentInit when the component's view has been initialized. Applies to components only.
    //Add 'implements AfterViewInit' to the class.
    
  }

  fetchData(buildingSelected, categorySelected, statusSelected) {
    this.deviceService
      .getDeviceData(buildingSelected, categorySelected, statusSelected)
      .subscribe((res) => {
        this.filteredRows = res.results.data;
        console.log(this.filteredRows);
      });
  }

  dataListMaster() {
    this.monitoringApiService.getMasterListData().subscribe((data) => {
      const dataCategory = data.data.find(
        (item) => item.name === "master_category"
      ).headerDetailParam;
      const dataStatus = data.data.find(
        (item) => item.name === "master_status"
      ).headerDetailParam;
      this.dataMasterCategori = dataCategory.filter(
        (item) => item.status === "2"
      );
      this.dataMasterStatus = dataStatus.filter((item) => item.status === "2");
    });
  }

  dataListBuilding() {
    this.monitoringApiService.getBuildingList().subscribe((data) => {
      this.dataBuildingList = data.data.filter((item) => item.statusId === 2);
    });
  }

  doFilter() {
    this.spinnerFilterActive = true;
    this.fetchData(
      this.buildingSelected,
      this.categorySelected,
      this.statusSelected
    );
    setTimeout(() => {
      this.spinnerFilterActive = false;
    }, 3000);
  }

  onClick(videoUrl: string) {
    const iframe = this.videoIframe.nativeElement;
    iframe.src = videoUrl;
  }
}
